@@ -39,7 +39,7 @@ setAs("genind", "genpop", function(from, to) {
 
 setOldClass("ktab")
 setAs("genind", "ktab", function(from, to) {
-    if(!require(ade4)) stop("package ade4 is required")
+    ## if(!require(ade4)) stop("package ade4 is required")
     checkType(from)
     res <- ktab.data.frame(df=as.data.frame(from), blocks=from@loc.nall, rownames=from@ind.names,
                            colnames=unlist(from@all.names), tabnames=from@loc.names)
@@ -50,7 +50,7 @@ setAs("genind", "ktab", function(from, to) {
 
 
 setAs("genpop", "ktab", function(from, to) {
-    if(!require(ade4)) stop("package ade4 is required")
+    ## if(!require(ade4)) stop("package ade4 is required")
     checkType(from)
     res <- ktab.data.frame(df=as.data.frame(from), blocks=from@loc.nall, rownames=from@pop.names,
                            colnames=unlist(from@all.names), tabnames=from@loc.names)
