@@ -25,7 +25,7 @@ spca <- function(obj, xy=NULL, cn=NULL, matWeight=NULL,
     if(!any(inherits(obj,c("genind","genpop")))) stop("obj must be a genind or genpop object.")
     invisible(validObject(obj))
     ## checkType(obj)
-    if(!require(ade4, quietly=TRUE)) stop("ade4 library is required.")
+    ## if(!require(ade4, quietly=TRUE)) stop("ade4 library is required.")
     if(!require(spdep, quietly=TRUE)) stop("spdep library is required.")
 
 
@@ -190,7 +190,7 @@ print.spca <- function(x, ...){
 ########################
 summary.spca <- function (object, ..., printres=TRUE) {
   if (!inherits(object, "spca"))stop("to be used with 'spca' object")
-  if(!require(ade4,quietly=TRUE)) stop("the library ade4 is required; please install this package")
+  ## if(!require(ade4,quietly=TRUE)) stop("the library ade4 is required; please install this package")
   if(!require(spdep,quietly=TRUE)) stop("the library spdep is required; please install this package")
 
   #util <- function(n) { ## no longer used
@@ -313,7 +313,7 @@ summary.spca <- function (object, ..., printres=TRUE) {
 plot.spca <- function (x, axis = 1, useLag=FALSE, ...){
     if (!inherits(x, "spca")) stop("Use only with 'spca' objects.")
 
-    if(!require(ade4)) stop("ade4 package is required.")
+    ## if(!require(ade4)) stop("ade4 package is required.")
     if(!require(spdep)) stop("spdep package is required.")
     if(axis>ncol(x$li)) stop("wrong axis required.")
 
